@@ -36,6 +36,7 @@ def make_client(client_cls, app, dsn=None):
         **convert_options(
             app.config,
             defaults={
+                'dsn': dsn,
                 'include_paths': (
                     set(app.config.get('SENTRY_INCLUDE_PATHS', []))
                     | set([app.import_name])
@@ -114,6 +115,10 @@ class Sentry(object):
 
     @property
     def last_event_id(self):
+        try:
+            return g.sentry_event_id
+        except Exception:
+            pass
         return getattr(self, '_last_event_id', None)
 
     @last_event_id.setter
@@ -211,6 +216,9 @@ class Sentry(object):
 
     def before_request(self, *args, **kwargs):
         self.last_event_id = None
+
+        self.client.transaction.push(request.url_rule.rule)
+
         try:
             self.client.http_context(self.get_http_info(request))
         except Exception as e:
@@ -224,6 +232,7 @@ class Sentry(object):
         if self.last_event_id:
             response.headers['X-Sentry-ID'] = self.last_event_id
         self.client.context.clear()
+        self.client.transaction.pop(request.url_rule.rule)
         return response
 
     def init_app(self, app, dsn=None, logging=None, level=None,
